==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/docking_notify/translations/docking_notify_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>@default</name>
    <message>
        <source>Notification</source>
        <translation>Benachrichtigung</translation>
    </message>
    <message>
        <source>Tray Icon Balloon</source>
        <translation>Sprechblase im Systemabschnitt der Kontrollleiste</translation>
    </message>
    <message>
        <source>Timeout</source>
        <translation>Timeout</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation>
            <numerusform>%n Sekunde</numerusform>
            <numerusform>%n Sekunden</numerusform>
        </translation>
    </message>
    <message>
        <source>Notification icon</source>
        <translation>Benachrichtigungssymbol</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritisch</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Syntax</source>
        <translation>Syntax</translation>
    </message>
    <message>
        <source>No Icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Qt4NotifyConfigurationWidget</name>
    <message>
        <source>Configure</source>
        <translation>Konfigurieren</translation>
    </message>
    <message>
        <source>Tray icon balloon&apos;s look configuration</source>
        <translation>Konfiguration der Sprechblase im Systemabschnitt der Kontrollleiste</translation>
    </message>
    <message>
        <source>
%&amp;t - title (eg. New message) %&amp;m - notification text (eg. Message from Jim), %&amp;d - details (eg. message quotation),
%&amp;i - notification icon</source>
        <translation>
%&amp;t - Titel (z.B. Neue Nachricht) %&amp;m - Nachrichtentext (z.B. Nachricht vom Jim), %&amp;d - Details (z.B. Nachrichteninhalt),
%&amp;i - Benachrichtigungssymbol</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/docking_notify/translations/docking_notify_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>@default</name>
    <message>
        <source>Notification</source>
        <translation>Benachrichtigung</translation>
    </message>
    <message>
        <source>Tray Icon Balloon</source>
        <translation>Sprechblase im Systemabschnitt der Kontrollleiste</translation>
    </message>
    <message>
        <source>Timeout</source>
        <translation>Timeout</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation>
            <numerusform>%n Sekunde</numerusform>
            <numerusform>%n Sekunden</numerusform>
        </translation>
    </message>
    <message>
        <source>Notification icon</source>
        <translation>Benachrichtigungssymbol</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritisch</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Syntax</source>
        <translation>Syntax</translation>
    </message>
    <message>
        <source>No Icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DockingNotifyConfigurationWidget</name>
    <message>
        <source>Configure</source>
        <translation type="unfinished">Konfigurieren</translation>
    </message>
    <message>
        <source>Tray icon balloon&apos;s look configuration</source>
        <translation type="unfinished">Konfiguration der Sprechblase im Systemabschnitt der Kontrollleiste</translation>
    </message>
    <message>
        <source>
%&amp;t - title (eg. New message) %&amp;m - notification text (eg. Message from Jim), %&amp;d - details (eg. message quotation),
%&amp;i - notification icon</source>
        <translation type="unfinished">
%&amp;t - Titel (z.B. Neue Nachricht) %&amp;m - Nachrichtentext (z.B. Nachricht vom Jim), %&amp;d - Details (z.B. Nachrichteninhalt),
%&amp;i - Benachrichtigungssymbol</translation>
    </message>
</context>
</TS>
